==> dde-file-manager_5.2.18.orig.tar.xz: dde-file-manager-5.2.18/src/dde-dock-plugins/disk-mount/translations/dde-disk-mount-plugin_hu.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="hu" version="2.1">
<context>
    <name>DUMountManager</name>
    <message>
        <source>Authentication timed out</source>
        <translation>A hitelesítés lejárt</translation>
    </message>
    <message>
        <source>Disk is busy, cannot unmount now</source>
        <translation>A lemez használatban van, jelenleg nem választható le</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>A lemez használatban van, jelenleg nem választható le</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation>Az eszköz használatban van, jelenleg nem választható le</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation>Az eszköz használatban van, jelenleg nem távolítható el</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Volume</source>
        <translation>%1 kötet</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown</source>
        <translation>Ismeretlen</translation>
    </message>
</context>
<context>
    <name>DiskControlWidget</name>
    <message>
        <source>dde-file-manager</source>
        <translation>dde-fájlkezelő</translation>
    </message>
    <message>
        <source>The device was not safely removed</source>
        <translation>Az eszközt nem sikerült biztonságosan eltávolítani</translation>
    </message>
    <message>
        <source>Click &quot;Safely Remove&quot; and then disconnect it next time</source>
        <translation>Kattintson a &quot;Biztonságos eltávolítás&quot; gombra, majd csatlakoztassa le később</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation type="vanished">Az eszköz használatban van, jelenleg nem választható le</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation type="vanished">Az eszköz használatban van, jelenleg nem távolítható el</translation>
    </message>
    <message>
        <source>Cannot unmount the device</source>
        <translation>Eszköz nem leválasztható</translation>
    </message>
    <message>
        <source>The disk is mounted by user &quot;%1&quot;, you cannot unmount it.</source>
        <translation>A lemez &quot;%1&quot; felhasználó által felcsatolva, a leválasztása nem lehetséges.</translation>
    </message>
    <message>
        <source>Cannot find the mounted device</source>
        <translation>Nem található a csatlakoztatott eszköz</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Lemezek</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Lemez</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Megnyitás</translation>
    </message>
    <message>
        <source>Eject all</source>
        <translation>Az összes kiadása</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The device has been safely removed</source>
        <translation>Az eszköz biztonságosan eltávolítva</translation>
    </message>
    <message>
        <source>Access denied</source>
        <translation>Hozzáférés megtagadva</translation>
    </message>
    <message>
        <source>You do not have permission to access this folder</source>
        <translation>Nincs jogosultsága a mappához való hozzáféréséhez</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Megerősítés</translation>
    </message>
    <message>
        <source>Scanning the device, stop it?</source>
        <translation>Az eszköz ellenőrzése, biztos benne hogy leállítja?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Mégsem</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Leállítás</translation>
    </message>
</context>
</TS>

==> dde-file-manager_5.6.4.orig.tar.xz: dde-file-manager-5.6.4/src/dde-dock-plugins/disk-mount/translations/dde-disk-mount-plugin_hu.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hu">
<context>
    <name>DUMountManager</name>
    <message>
        <source>Authentication timed out</source>
        <translation>A hitelesítés lejárt</translation>
    </message>
    <message>
        <source>Disk is busy, cannot unmount now</source>
        <translation>A lemez használatban van, jelenleg nem választható le</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>A lemez használatban van, jelenleg nem választható le</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation>Az eszköz használatban van, jelenleg nem választható le</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation>Az eszköz használatban van, jelenleg nem távolítható el</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Volume</source>
        <translation>%1 kötet</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown</source>
        <translation>Ismeretlen</translation>
    </message>
</context>
<context>
    <name>DiskControlWidget</name>
    <message>
        <source>dde-file-manager</source>
        <translation>dde-fájlkezelő</translation>
    </message>
    <message>
        <source>The device was not safely removed</source>
        <translation>Az eszközt nem sikerült biztonságosan eltávolítani</translation>
    </message>
    <message>
        <source>Click &quot;Safely Remove&quot; and then disconnect it next time</source>
        <translation>Kattintson a &quot;Biztonságos eltávolítás&quot; gombra, majd csatlakoztassa le később</translation>
    </message>
    <message>
        <source>Cannot unmount the device</source>
        <translation>Eszköz nem leválasztható</translation>
    </message>
    <message>
        <source>The disk is mounted by user &quot;%1&quot;, you cannot unmount it.</source>
        <translation>A lemez &quot;%1&quot; felhasználó által felcsatolva, a leválasztása nem lehetséges.</translation>
    </message>
    <message>
        <source>Cannot find the mounted device</source>
        <translation>Nem található a csatlakoztatott eszköz</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Lemezek</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Lemez</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Megnyitás</translation>
    </message>
    <message>
        <source>Eject all</source>
        <translation>Az összes kiadása</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The device has been safely removed</source>
        <translation>Az eszköz biztonságosan eltávolítva</translation>
    </message>
    <message>
        <source>Access denied</source>
        <translation>Hozzáférés megtagadva</translation>
    </message>
    <message>
        <source>You do not have permission to access this folder</source>
        <translation>Nincs jogosultsága a mappához való hozzáféréséhez</translation>
    </message>
    <message>
        <source>Scanning the device, stop it?</source>
        <translation>Az eszköz ellenőrzése, biztos benne hogy leállítja?</translation>
    </message>
    <message>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Megerősítés</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Mégsem</translation>
    </message>
    <message>
        <source>Stop</source>
        <comment>button</comment>
        <translation>Leállítás</translation>
    </message>
</context>
</TS>
